<?php

class Followthis_Admin_Options {

	var $settings_page;

	/**
	 * @since 1.0
	 */
	public function __construct() {
		/* Set up the administration functionality. */
		add_action( 'admin_menu', array( &$this, 'settings_page_init' ) );
	}

	/**
	 * Adds an additional menu item under the Settings menu.
	 * Loads actions specifically for the followthis settings page.
	 *
	 * @since 1.0
	 */
	function settings_page_init() {

		if ( isset( $_GET['followthis_retag'] ) ) {
			Followthis::retag_posts();
			wp_redirect( admin_url( 'options-general.php?page=followthis' ) );
		}

		/* Add wpLike2get settings page. */
		$this->settings_page = add_options_page( __( 'followthis', 'followthis' ), __( 'followthis', 'followthis' ), 'manage_options', 'followthis', array( &$this, 'settings_page' ) );

		/* Register the theme settings. */
		add_action( 'admin_init', array( &$this, 'register_settings' ) );

		/* Add default settings if none are present. */
		add_action( "load-{$this->settings_page}", array( &$this, 'load_settings_page' ) );

		/* Add media for the settings page. */
		add_action( "load-{$this->settings_page}", array( &$this, 'admin_enqueue_style' ) );
		add_action( "load-{$this->settings_page}", array( &$this, 'settings_page_media' ) );
		add_action( "admin_head-{$this->settings_page}", array( &$this, 'settings_page_scripts' ) );

		/* Load the meta boxes. */
		add_action( "load-{$this->settings_page}", array( &$this, 'load_meta_boxes' ) );

		/* Create a hook for adding meta boxes. */
		add_action( "load-{$this->settings_page}", array( &$this, 'add_meta_boxes' ) );
	}

	/**
	 * Adds the default followthis settings to the database if they have not been set.
	 *
	 * @since 1.0
	 */
	function load_settings_page() {
		/* Get settings from the database. */
		$settings = get_option( 'followthis_options' );

		/* If no settings are available, add the default settings to the database. */
		if ( $settings === FALSE ) {
			$settings = $this->default_settings();
			add_option( 'followthis_options', $settings, '', 'yes' );

			/* Redirect the page so that the settings are reflected on the settings page. */
			wp_redirect( admin_url( 'options-general.php?page=followthis' ) );
			exit;
		}
	}

	/**
	 * Registers the followthis settings.
	 * @uses  register_setting() to add the settings to the database.
	 *
	 * @since 1.0
	 */
	function register_settings() {
		register_setting( 'followthis_plugin_settings', 'followthis_options', array( &$this, 'sanitize_followthis_options' ) );
	}

	/**
	 * Returns an array of the default plugin settings.  These are only used on initial setup.
	 *
	 * @since 1.0
	 */
	function default_settings() {
		return array(
			'keywords' => ''
		);
	}

	/**
	 * using the sanitization callback for retagging posts
	 */
	function sanitize_followthis_options( $input ) {
		// retagg posts
		Followthis::retag_posts( $input['keywords'] );

		return $input;
	}

	/**
	 * Executes the 'add_meta_boxes' action hook because WordPress doesn't fire this on custom admin pages.
	 *
	 * @since 1.0
	 */
	function add_meta_boxes() {
		$plugin_data = get_plugin_data( dirname( __FILE__ ) . '/followthis.php' );
		do_action( 'add_meta_boxes', $this->settings_page, $plugin_data );
	}

	/**
	 * Loads the plugin settings page meta boxes.
	 *
	 * @since 1.0
	 */
	function load_meta_boxes() {
		require_once( plugin_basename( 'Followthis_Meta_Box.php' ) );
	}

	/**
	 * Displays the HTML and meta boxes for the plugin settings page.
	 *
	 * @since 1.0
	 */
	function settings_page() {
		?>

		<div class="wrap">

			<?php screen_icon( 'followthis' ); ?>

			<h2><?php _e( 'followthis Settings', 'followthis' ); ?></h2>

			<div id="poststuff">

				<div class="metabox-holder has-right-sidebar">
					<div class="inner-sidebar"><?php do_meta_boxes( $this->settings_page, 'side', null ); ?></div>
					<div id="post-body">
						<form method="post" action="options.php">
							<?php settings_fields( 'followthis_plugin_settings' ); ?>
							<?php wp_nonce_field( 'closedpostboxes', 'closedpostboxesnonce', false ); ?>
							<?php wp_nonce_field( 'meta-box-order', 'meta-box-order-nonce', false ); ?>
							<div id="post-body-content"><?php do_meta_boxes( $this->settings_page, 'normal', null ); ?></div>
							<?php submit_button( __( 'enter default topics in empty posts', 'followthis' ) ); ?>
							<?php _e( 'By clicking all posts with no tags are filled automatically with these default topics and topics extracted from your post (source: your text, titles)', 'followthis' ); ?>
						</form>
					</div>
				</div>

				<br class="clear">

			</div>
			<!-- #poststuff -->

		</div><!-- .wrap --><?php
	}

	/**
	 * Loads the admin stylesheet for the plugin settings page.
	 *
	 * @since 1.0
	 */
	function admin_enqueue_style() {
//		wp_enqueue_style( 'followthis-admin', plugin_basename( 'css/admin.css' ), false, 1.0, 'screen' );
	}

	/**
	 * Loads needed JavaScript files for handling the meta boxes on the settings page.
	 *
	 * @since 1.0
	 */
	function settings_page_media() {
		wp_enqueue_script( 'common' );
		wp_enqueue_script( 'wp-lists' );
		wp_enqueue_script( 'postbox' );
	}

	/**
	 * Loads JavaScript for handling the open/closed state of each meta box.
	 *
	 * @since 1.0
	 */
function settings_page_scripts() {
	?>
	<script type="text/javascript">
		//<![CDATA[
		jQuery(document).ready(function ($) {
			$('.if-js-closed').removeClass('if-js-closed').addClass('closed');
			postboxes.add_postbox_toggles('<?php echo $this->settings_page; ?>');
		});
		//]]>
	</script>
<?php
}
}

$ft_options = new Followthis_Admin_Options();